Title: Data Only: Searching for Footprints of Selection using Haplotype Homozygosity Based Tests
Version: 1.0.1
Description: Contains example data for the 'rehh' package.
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
Depends: R (≥ 2.10)
Encoding: UTF-8
LazyData: true
NeedsCompilation: no
Packaged: 2026-05-04 12:57:00 UTC; mathieu
Author: Mathieu Gautier [aut, cre], Alexander Klassmann [aut], Renaud Vitalis [aut]
Maintainer: Mathieu Gautier <mathieu.gautier@inrae.fr>
Repository: CRAN
Date/Publication: 2026-05-04 15:00:13 UTC

Data Only: Searching for Footprints of Selection using Haplotype Homozygosity Based Tests Description: Contains example data for the 'rehh' package.

Description

Contains example data for the package rehh.

Details

Package: rehh.data
Version: 1.0.0
License: GPL(>=2)

Index:

wgscan.cgu              Whole genome scan results for the CGU
                        (Creole from Guadeloupe island)
wgscan.eut              Whole genome scan results for a pool of
                        European taurine cattle

References

Gautier M., Klassmann A., and Vitalis R. (2017). rehh 2.0: a reimplementation of the R package rehh to detect positive selection from haplotype structure. Molecular Ecology Resources, 17, 78–90.

Gautier M. and Vitalis R. (2012). rehh: An R package to detect footprints of selection in genome-wide SNP data from haplotype structure. Bioinformatics, 28(8), 1176–1177.

Gautier, M. and Naves, M. (2011). Footprints of selection in the ancestral admixture of a New World Creole cattle breed. Molecular Ecology, 20, 3128–3143.


Whole genome scan results for the CGU (Creole from Guadeloupe island)

Description

A dataframe object with of 44,057 rows (SNPs) and 7 columns: i) chromosome name (CHR), ii) position of the SNP in bp (POSITION), iii) Ancestral allele frequency (freq_A), iv) iHH for the ancestral allele (iHH_A), v) iHH for the derived allele (iHH_D), vi) iES using the estimator by Tang et al. (2007) (iES_Tang_et_al_2007), vii) iES using the estimator by Sabeti et al. (2007) (iES_Sabeti_et_al_2007).

Usage

data(wgscan.cgu)

References

Gautier, M. and Naves, M. (2011). Footprints of selection in the ancestral admixture of a New World Creole cattle breed. Molecular Ecology, 20, 3128–3143.


Whole genome scan results for a pool of European taurine cattle

Description

A dataframe object with 44,057 rows (SNPs) and 7 columns: i) chromosome name (CHR), ii) position of the SNP in bp (POSITION), iii) Ancestral allele frequency (freq_A), iv) iHH for the ancestral allele (iHH_A), v) iHH for the derived allele (iHH_D), vi) iES using the estimator by Tang et al. (2007) (iES_Tang_et_al_2007), vii) iES using the estimator by Sabeti et al. (2007) (iES_Sabeti_et_al_2007).

Usage

data(wgscan.eut)

References

Gautier, M. and Naves, M. (2011). Footprints of selection in the ancestral admixture of a New World Creole cattle breed. Molecular Ecology, 20, 3128–3143.